#ifndef QT_FEATURES_ScxmlGlobalPrivate_src_global_qtscxmlglobal_config_h_H
#define QT_FEATURES_ScxmlGlobalPrivate_src_global_qtscxmlglobal_config_h_H


#define QT_VERSION_STR "6.11.1"

#define QT_VERSION_MAJOR 6

#define QT_VERSION_MINOR 11

#define QT_VERSION_PATCH 1

#endif // QT_FEATURES_ScxmlGlobalPrivate_src_global_qtscxmlglobal_config_h_H
